@@ -48,6 +48,6 @@ int
 time_picker_get_minute (TimePicker *time_picker);
 
 
-TimePicker *time_picker_new ();
+TimePicker *time_picker_new (void);
 
 G_END_DECLS
