@@ -39,6 +39,10 @@ struct _PicplannerOverview
   GtkWidget           *switch_moon;
   GtkWidget           *switch_milky_way;
 
+  GtkWidget           *switch_to_sun_stack;
+  GtkWidget           *switch_to_moon_stack;
+  GtkWidget           *switch_to_milky_way_stack;
+
   GtkWidget           *label_sun_rise;
   GtkWidget           *label_sun_set;
   GtkWidget           *label_moon_rise;
@@ -82,6 +86,42 @@ struct _PicplannerOverview
 
 
 G_DEFINE_TYPE (PicplannerOverview, picplanner_overview, GTK_TYPE_BOX)
+
+/*
+ * Catch all signals from the buttons and emit a signal which can be used by
+ * picplanner-window to change the stack page.
+ */
+static guint signal_button_pressed;
+static void
+change_stack_page (GtkButton *self,
+                   gpointer user_data)
+{
+  int stack_page = 0;
+  PicplannerOverview *overview = user_data;
+
+  if (self == GTK_BUTTON(overview->switch_to_sun_stack))
+    {
+      g_print("Button Sun\n");
+      stack_page = 1;
+    }
+  else if (self == GTK_BUTTON(overview->switch_to_moon_stack))
+    {
+      g_print("Button Moon\n");
+      stack_page = 2;
+    }
+  else if (self == GTK_BUTTON(overview->switch_to_milky_way_stack))
+    {
+      g_print("Button Milky Way\n");
+      stack_page = 3;
+    }
+
+
+  g_signal_emit (overview,
+                 signal_button_pressed,
+                 0, stack_page);
+}
+
+
 static gboolean
 input_rebounce_reset_signal (gpointer user_data)
 {
@@ -109,6 +149,9 @@ input_timeout_signal (gpointer user_data)
       g_settings_set_double (overview->settings,
                              "latitude" ,
                              shumate_location_get_latitude (SHUMATE_LOCATION(overview->viewport)));
+      g_settings_set_double (overview->settings,
+                             "zoom-level",
+                             shumate_viewport_get_zoom_level (overview->viewport));
       g_source_remove (overview->input_timeout_id);
     }
   overview->input_count = 0;
@@ -120,10 +163,10 @@ input_changed (GtkWidget *self,
                gpointer user_data,
                gpointer data_overview)
 {
-  (void) user_data;
   PicplannerOverview *overview;
   overview = PICPLANNER_OVERVIEW (data_overview);
 
+  (void) user_data;
   if (!overview->input_currently)
     {
       if (!G_IS_SETTINGS(self) && !PICPLANNER_IS_OVERVIEW (self))
@@ -135,14 +178,16 @@ input_changed (GtkWidget *self,
                                                           input_timeout_signal,
                                                           overview);
             }
+          //picplanner_overview_remove_map_content (overview);
+          // TODO: Remove content asynchronous?
           overview->input_count++;
-          picplanner_overview_remove_map_content (overview);
         }
       else
         {
           shumate_location_set_location (SHUMATE_LOCATION (overview->viewport),
                                          g_settings_get_double (overview->settings, "latitude"),
                                          g_settings_get_double (overview->settings, "longitude"));
+          shumate_viewport_set_zoom_level (overview->viewport, g_settings_get_double (overview->settings, "zoom-level"));
         }
     }
 }
@@ -159,14 +204,14 @@ picplanner_overview_set_current_coordinates_sun (PicplannerOverview *overview,
                                                  int                current_index,
                                                  GDateTime          *date_time)
 {
-  char *char_elevation_sun;
-  char *char_azimuth_sun;
-  char *char_sun_rise;
-  char *char_sun_set;
+  g_autofree char *char_elevation_sun = NULL;
+  g_autofree char *char_azimuth_sun = NULL;
+  g_autofree char *char_sun_rise = NULL;
+  g_autofree char *char_sun_set = NULL;
 
-  GDateTime *date_time_noon;
-  GDateTime *date_time_rise;
-  GDateTime *date_time_set;
+  g_autoptr (GDateTime) date_time_noon = NULL;
+  g_autoptr (GDateTime) date_time_rise = NULL;
+  g_autoptr (GDateTime) date_time_set = NULL;
 
   date_time_noon = g_date_time_new (g_date_time_get_timezone (date_time),
                                     g_date_time_get_year (date_time),
@@ -207,14 +252,6 @@ picplanner_overview_set_current_coordinates_sun (PicplannerOverview *overview,
   gtk_label_set_text (GTK_LABEL (overview->label_sun_set), char_sun_set);
   gtk_label_set_text (GTK_LABEL (overview->label_elevation_sun), char_elevation_sun);
   gtk_label_set_text (GTK_LABEL (overview->label_azimuth_sun), char_azimuth_sun);
-
-  g_date_time_unref (date_time_rise);
-  g_date_time_unref (date_time_set);
-
-  g_free (char_sun_rise);
-  g_free (char_sun_set);
-  g_free (char_elevation_sun);
-  g_free (char_azimuth_sun);
 }
 
 
@@ -231,14 +268,14 @@ picplanner_overview_set_current_coordinates_moon (PicplannerOverview  *overview,
                                                   int                 current_index,
                                                   GDateTime           *date_time)
 {
-  char *char_elevation_moon;
-  char *char_azimuth_moon;
-  char *char_moon_rise;
-  char *char_moon_set;
+  g_autofree char *char_elevation_moon = NULL;
+  g_autofree char *char_azimuth_moon = NULL;
+  g_autofree char *char_moon_rise = NULL;
+  g_autofree char *char_moon_set = NULL;
 
-  GDateTime *date_time_noon;
-  GDateTime *date_time_rise;
-  GDateTime *date_time_set;
+  g_autoptr (GDateTime) date_time_noon = NULL;
+  g_autoptr (GDateTime) date_time_rise = NULL;
+  g_autoptr (GDateTime) date_time_set = NULL;
 
   date_time_noon = g_date_time_new (g_date_time_get_timezone (date_time),
                                     g_date_time_get_year (date_time),
@@ -278,15 +315,6 @@ picplanner_overview_set_current_coordinates_moon (PicplannerOverview  *overview,
   gtk_label_set_text (GTK_LABEL (overview->label_moon_set), char_moon_set);
   gtk_label_set_text (GTK_LABEL (overview->label_elevation_moon), char_elevation_moon);
   gtk_label_set_text (GTK_LABEL (overview->label_azimuth_moon), char_azimuth_moon);
-
-  g_date_time_unref (date_time_rise);
-  g_date_time_unref (date_time_set);
-
-
-  g_free (char_moon_rise);
-  g_free (char_moon_set);
-  g_free (char_elevation_moon);
-  g_free (char_azimuth_moon);
 }
 
 
@@ -303,14 +331,14 @@ picplanner_overview_set_current_coordinates_milky_way (PicplannerOverview *overv
                                                        int                current_index,
                                                        GDateTime          *date_time)
 {
-  char *char_elevation_milky_way;
-  char *char_azimuth_milky_way;
-  char *char_milky_way_rise;
-  char *char_milky_way_set;
+  g_autofree char *char_elevation_milky_way = NULL;
+  g_autofree char *char_azimuth_milky_way = NULL;
+  g_autofree char *char_milky_way_rise = NULL;
+  g_autofree char *char_milky_way_set = NULL;
 
-  GDateTime *date_time_noon;
-  GDateTime *date_time_rise;
-  GDateTime *date_time_set;
+  g_autoptr (GDateTime) date_time_noon = NULL;
+  g_autoptr (GDateTime) date_time_rise = NULL;
+  g_autoptr (GDateTime) date_time_set = NULL;
 
   date_time_noon = g_date_time_new (g_date_time_get_timezone (date_time),
                                     g_date_time_get_year (date_time),
@@ -350,14 +378,6 @@ picplanner_overview_set_current_coordinates_milky_way (PicplannerOverview *overv
   gtk_label_set_text (GTK_LABEL (overview->label_milky_way_set), char_milky_way_set);
   gtk_label_set_text (GTK_LABEL (overview->label_elevation_milky_way), char_elevation_milky_way);
   gtk_label_set_text (GTK_LABEL (overview->label_azimuth_milky_way), char_azimuth_milky_way);
-
-  g_date_time_unref (date_time_rise);
-  g_date_time_unref (date_time_set);
-
-  g_free (char_milky_way_rise);
-  g_free (char_milky_way_set);
-  g_free (char_elevation_milky_way);
-  g_free (char_azimuth_milky_way);
 }
 
 
@@ -604,13 +624,14 @@ shumate_map_metric_imperial_scale (GSettings  *settings,
                                    gchar      *key,
                                    gpointer   user_data)
 {
-  (void) settings;
-  (void) key;
   PicplannerOverview *overview = user_data;
   ShumateScale *scale;
   gboolean metric;
   gboolean imperial;
 
+  (void) settings;
+  (void) key;
+
   scale = shumate_simple_map_get_scale (overview->map);
   metric = g_settings_get_boolean (settings, "map-unit-metric");
   imperial = g_settings_get_boolean (settings, "map-unit-imperial");
@@ -706,14 +727,10 @@ picplanner_overview_init (PicplannerOverview *overview)
                     "changed::latitude",
                     G_CALLBACK (input_changed),
                     overview);
-
-  g_settings_bind (overview->settings, "map-fullscreen",
-                   overview->basic_information, "visible",
-                   G_SETTINGS_BIND_INVERT_BOOLEAN);
-
-  g_settings_bind (overview->settings, "zoom-level",
-                   overview->viewport, "zoom-level",
-                   G_SETTINGS_BIND_DEFAULT);
+  g_signal_connect (G_OBJECT (overview->viewport),
+                    "notify::zoom-level",
+                    G_CALLBACK (input_changed),
+                    overview);
 
   g_settings_bind (overview->settings, "sun-visible",
                    overview->switch_sun, "active",
@@ -745,6 +762,23 @@ picplanner_overview_init (PicplannerOverview *overview)
                     G_CALLBACK (shumate_map_metric_imperial_scale),
                     overview);
 
+  /*
+   * Register the button presses to switch the few
+   */
+
+  g_signal_connect (G_OBJECT (overview->switch_to_sun_stack),
+                    "clicked",
+                    G_CALLBACK (change_stack_page),
+                    overview);
+  g_signal_connect (G_OBJECT (overview->switch_to_moon_stack),
+                    "clicked",
+                    G_CALLBACK (change_stack_page),
+                    overview);
+  g_signal_connect (G_OBJECT (overview->switch_to_milky_way_stack),
+                    "clicked",
+                    G_CALLBACK (change_stack_page),
+                    overview);
+
 
   /*
    * Initialisation of values needed to detect when a user input ends
@@ -769,6 +803,9 @@ picplanner_overview_class_init (PicplannerOverviewClass *class)
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, switch_sun);
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, switch_moon);
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, switch_milky_way);
+  gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, switch_to_sun_stack);
+  gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, switch_to_moon_stack);
+  gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, switch_to_milky_way_stack);
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, label_sun_rise);
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, label_sun_set);
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, label_moon_rise);
@@ -782,10 +819,17 @@ picplanner_overview_class_init (PicplannerOverviewClass *class)
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, label_azimuth_moon);
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, label_azimuth_milky_way);
   gtk_widget_class_bind_template_child (GTK_WIDGET_CLASS (class), PicplannerOverview, basic_information);
+
+  signal_button_pressed = g_signal_new ("change-stack",
+                                        G_OBJECT_CLASS_TYPE (class),
+                                        G_SIGNAL_RUN_LAST,
+                                        0, NULL, NULL, NULL,
+                                        G_TYPE_NONE,
+                                        1, G_TYPE_INT);
 }
 
 PicplannerOverview *
-picplanner_overview_new ()
+picplanner_overview_new (void)
 {
   return g_object_new (PICPLANNER_OVERVIEW_TYPE, NULL);
 }
